## Changes

<!-- What does this PR do? -->

## Testing

<!-- How was this tested? -->

## Checklist

- [ ] Tests pass (`pytest`)
- [ ] Linting passes (`ruff check .`)
- [ ] Types check (`mypy polymarket_us`)
